@@ -3,7 +3,8 @@ from typing import Union, NewType, Optional, List, Dict, Final
 import ipywidgets as widgets
 import k3d
 import numpy as np
-from k3d.objects import Group, Line, Points, TextureText, Drawable
+from IPython.display import display
+from k3d.objects import Group, Line, Points, Text, Drawable
 from k3d.plot import Plot
 
 from .jointset import JointSet, MuPoTSJoints, OpenPoseJoints, CocoExJoints, PanopticJoints, Common14Joints
@@ -19,12 +20,13 @@ DEFAULT_COLORS: Final[Dict[str, int]] = {
 
 
 class DrawableSkeleton(Group):
-    def __init__(self, joint_points: Points, joint_lines: List[Line], joint_names: List[TextureText]):
-        drawable_objects: List[Drawable] = [joint_points] + joint_lines + joint_names
+    def __init__(self, joint_points: Points, joint_lines: List[Line], joint_names: List[Text]):
+        points: List[Drawable] = [joint_points]
+        drawable_objects: List[Drawable] = points + joint_lines + joint_names
         super().__init__(drawable_objects)
         self.joint_points: Points = joint_points
         self.joint_lines: List[Line] = joint_lines
-        self.joint_names: List[TextureText] = joint_names
+        self.joint_names: List[Text] = joint_names
 
     def hide_joint_names(self):
         for joint_name in self.joint_names:
@@ -46,7 +48,7 @@ class Skeleton:
     def to_drawable_skeleton(self) -> DrawableSkeleton:
         joint_points = self.get_joint_points()
         joint_lines: List[Line] = self.get_joint_lines()
-        joint_names: List[TextureText] = self.get_joint_names()
+        joint_names: List[Text] = self.get_joint_names()
         return DrawableSkeleton(joint_points, joint_lines, joint_names)
 
     def get_joint_colors(self) -> np.ndarray:
@@ -90,11 +92,11 @@ class Skeleton:
             for i in range(len(self.joint_set.limb_graph))
         ]
 
-    def get_joint_names(self) -> List[TextureText]:
-        return [k3d.texture_text(
+    def get_joint_names(self) -> List[Text]:
+        return [k3d.text(
             text=self.joint_set.names[i],
             position=self.joint_coordinates[i],
-            size=0.45, color=DEFAULT_COLORS.get('black'))
+            size=0.45, label_box=False, color=DEFAULT_COLORS.get('black'))
             for i in range(self.joint_set.number_of_joints)
         ]
 
@@ -112,6 +114,7 @@ class SkeletonVisualizer:
         self.plot: SkeletonPlot = None
         self.size_scalar: float = size_scalar
         self.skeletons: List[DrawableSkeleton] = []
+        self.joint_name_visibility_button = widgets.Button(description="Hide joint names")
 
     def visualize(self, skeletons: np.ndarray, colors: List[Color] = None):
         self.__assert_visualization_arguments(skeletons, colors)
@@ -119,8 +122,8 @@ class SkeletonVisualizer:
         if colors is None:
             colors = ['default' for i in range(number_of_skeletons)]
         self.plot = self.__create_skeleton_plot(skeletons, colors)
-        for skeleton in self.skeletons:
-            skeleton.hide_joint_names()
+        self.joint_name_visibility_button.on_click(callback=self.__hide_skeleton_joint_names, remove=True)
+        display(objs=self.joint_name_visibility_button)
         self.plot.display()
 
     def __assert_visualization_arguments(self, skeletons: np.ndarray, colors: List[Color]):
@@ -151,6 +154,18 @@ class SkeletonVisualizer:
         max_values = [abs(skeleton).max() for skeleton in skeletons]
         return (min(max_values) / 50.0) * self.size_scalar
 
+    def __hide_skeleton_joint_names(self):
+        for skeleton in self.skeletons:
+            skeleton.hide_joint_names()
+        self.joint_name_visibility_button.description = "Show joint names"
+        self.joint_name_visibility_button.on_click(callback=self.__show_skeleton_joint_names(), remove=True)
+
+    def __show_skeleton_joint_names(self):
+        for skeleton in self.skeletons:
+            skeleton.show_joint_names()
+        self.joint_name_visibility_button.description = "Hide joint names"
+        self.joint_name_visibility_button.on_click(callback=self.__hide_skeleton_joint_names(), remove=True)
+
 
 class MuPoTSVisualizer(SkeletonVisualizer):
     def __init__(self, size_scalar: float = 1.0):
@@ -174,4 +189,4 @@ class PanopticVisualizer(SkeletonVisualizer):
 
 class Common14Visualizer(SkeletonVisualizer):
     def __init__(self, size_scalar: float = 1.0):
-        super().__init__(joint_set=Common14Joints(), size_scalar=size_scalar)
\ No newline at end of file
+        super().__init__(joint_set=Common14Joints(), size_scalar=size_scalar)
